.. _api-index:

###################
  The PyZMQ API
###################

:Release: |release|
:Date: |today|

.. toctree::

    zmq
    zmq.devices
    zmq.green
    generated/zmq.eventloop.ioloop
    generated/zmq.eventloop.zmqstream
    zmq.auth
    zmq.auth.thread
    zmq.auth.ioloop
    generated/zmq.log.handlers
    generated/zmq.ssh.tunnel
    generated/zmq.utils.jsonapi
    generated/zmq.utils.monitor
    generated/zmq.utils.z85
    zmq.utils.win32

